Materials and units
======================

These are the modules that deal with material properties and units. Together with the :doc:`structure modules <../Structures/structure>`, they form the backbone of Solcore.

.. toctree::
    :maxdepth: 2

    Materials
    Units
    NewMats